.. _configurationHelp:

===========
THEMA: Core
===========

The ``Core`` class is a data container class used for modeling in THEMA, working in the background so users don't have to. It provides access to three versions of the user's data: raw data, cleaned data, and projected data. This class is inherited by almost everything in THEMA, providing a central data handling mechanism to manage data in the background.

.. raw:: html

   <hr style="border: none; border-top: 2px solid #007bff; margin: 20px 0;">

.. _core:

Core Class
-----------------

.. automodule:: thema.core
   :members:
   :undoc-members:
   :show-inheritance:
   :noindex:
